@@ -2,10 +2,11 @@ import re
 from datetime import date, datetime
 
 from pysjtu import consts
-from pysjtu.client.api import CourseLibMixin, ExamMixin, GPAMixin, ScheduleMixin, ScoreMixin, SelectionMixin, ProfileMixin
+from pysjtu.client.api import CourseLibMixin, ExamMixin, GPAMixin, ScheduleMixin, ScoreMixin, SelectionMixin, \
+    ProfileMixin
 from pysjtu.client.base import BaseClient
 from pysjtu.session import BaseSession, Session
-from pysjtu.ocr import JCSSRecognizer
+from pysjtu.utils import forward_method_args
 
 
 class Client(ProfileMixin, SelectionMixin, ScheduleMixin, CourseLibMixin, ExamMixin, GPAMixin, ScoreMixin, BaseClient):
@@ -57,16 +58,15 @@ class Client(ProfileMixin, SelectionMixin, ScheduleMixin, CourseLibMixin, ExamMi
         return self._session._cache_store["student_id"]
 
 
-def create_client(username: str, password: str, use_jcss: bool = True, _mocker_app=None) -> Client:
+@forward_method_args(Session.__init__)
+def create_client(*args, **kwargs) -> Client:
     """
-    Create a new :class:`Client` with default options.
-    To change :class:`Session` settings or preserve your session, use :class:`Session` and :class:`Client` instead.
+    Create a new :class:`Client` with given options.
+
+    This is just a shortcut for ``Client(Session(*args, **kwargs))``.
+    To manipulate or reuse underlying Session object, use :class:`pysjtu.session.Session` and :class:`Client` instead.
 
-    :param username: JAccount username.
-    :param password: JAccount password.
-    :param use_jcss: Use JAccount Captcha Solver Service to recognize captcha instead of built-in ONNX based recognizer.
-    :param _mocker_app: An WSGI application to send requests to (for debug or test purposes).
     :return: an authenticated :class:`Client`.
     """
-    sess = Session(username=username, password=password, _mocker_app=_mocker_app, ocr=JCSSRecognizer() if use_jcss else None)
+    sess = Session(*args, **kwargs)
     return Client(session=sess)
